enough.community documentation
==============================

The `Enough infrastructure
<http://lab.enough.community/main/infrastructure>`_ are a set of
services (Forum, chat, shared storage, monitoring, backups, IDS, DNS,
etc.) to support the work of `the Enough community
<https://enough.community>`_. It is maintained by :doc:`individuals
<community/team>` organized `horizontally
<https://enough.community/blog/2020/01/20/manifesto/>`__. Anyone is
welcome to contribute: learn more in the :doc:`contribution guide
<community/contribute>`.

Enough is also suitable for organizations with a focus on human right
defenders and journalists. It can be used to create and maintain an
independant infrastructure.

.. toctree::
  :caption: Infrastructure guide
  :name: Infrastructure guide
  :maxdepth: 2

  introduction
  user-guide
  services/index
  community/index
